2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.2
===

Refresh package.

1.1
===

Refresh package.

1.0
===

Initial import from jaraco.net.
